#if defined _gamecms_present_included
  #endinput
#endif
#define _gamecms_present_included

/**Добавление презента
*
*	@prUnic - уникальный номер презента. 
*		Имеет сквозную нумерацию, не должен повторяться в других плагинах. Начальный номер - 5.
*	@prName- название презента
*	@prLimit- количество презентов за карту
*		-1 - нет лимита
*		-2 - запретить автоматический спавн по таймеру (только для ручного добавления)
*	@prAccess- доступ:
*		0 - всем
*		-1 - только террористам
*		-2 - только контр-террористам
*		-3 - только зарегистрированным
*	@prMinPlayers- мин. количество игроков
*	@prModel - название модели
*	@prSubModel - номер субмодели
*	@flTTL - время "жизни" модели, после которого она будет удалена, секунд
*		0.0 - удалится по общим правилам
*		-1.0 - не удалять, пока не поднимут презент
*	@return - 1- при удачном добавлении
*	Пример: CmsAddPresent(5, "+10 здоровья", 5, -3, 0, "health_kit");
*/
native CmsAddPresent(prUnic, prName[], prLimit=0, prAccess=0, prMinPlayers=0, prModel[]="",	prSubModel=0, Float:flTTL = 0.0)


/** Получение данных о презенте по его уникальному номеру
*	
*	@idKey - уникальный номер презента
*	@Data - массив с данными о презенте
*		Data[0] - доступ
*		Data[1] - мин. количество игроков для появления презента
*		Data[2] - количество (сколько может выпасть таких презентов)
*	@Name[]	- название презента
*	@Len 	- размер буфера для записи названия
*/
native CmsGetPresentInfoByKey(idKey, Data[3], Name[], Len)


/** Спавн презента по его уникальному номеру
*	
*	@idKey - уникальный номер презента (если 0- номер будет выбран рандомно из имеющихся)
*	@origin[3] - координаты для спавна презента (если 0.0- авто-определение из возможных точек)
*	@noanons - оповещение о появлении презента (true- тихий спавн, false- стандартное оповещение)
*	@owner - кому предназначен презент (параметр @prAccess при создании презента)
*	@flTime - время жизни презента (секунд до удаления. 0.0 - не удалять)
*	return - индекс созданного объекта
*/
native CmsSpawnPresentById(idKey, Float:origin[]={0.0, 0.0, 0.0}, bool:noanons = false, owner = 0, Float:flTime = 0.0)


/** Удаление презента из игры по параметрам
*	
*	@idKey - уникальный номер презента
*	@iOwner - владелец презента
*	@instant - удалить из базы презентов
*	@force - удаление всех выпавших презентов БЕЗ исключения
*	return - 1- при успешном удалении из базы
*/
native CmsRemovePresent(idKey = 0, iOwner = 0, bool:instant = false, bool:force = false)


/** Массив с уникальными номерами презентов
*	idKey = ArrayGetCell(Hahdle:array, index)
*	@idKey - уникальный номер презента из ячейки index
*/
native Array:CmsGetPresentsIndexes()

/** Количество зарегистрированных презентов
*	Вернет количество ячеек в массиве уникальных номеров
*/
native CmsGetPresentsCount()

/** Получение режима спавна презентов
*	@return - параметр режима
*		1- по-умолчанию, включен режим автоматического спавна, доступен ручной спавн
*		2- режим автоматического спавна Выключен, доступен Только ручной спавн
*		3- включен режим автоматического спавна по точкам из файла *map.spawns.cfg, доступен ручной спавн
*		0- отключить спавн презентов (по сути- временная приостановка работы плагина)
*/
native CmsPresentGetSpawnMode()

/** Переключение режима спавна презентов
*	@iMode - параметр режима
*		1- по-умолчанию, включен режим автоматического спавна, доступен ручной спавн
*		2- режим автоматического спавна Выключен, доступен Только ручной спавн
*		3- включен режим автоматического спавна по точкам из файла *map.spawns.cfg, доступен ручной спавн
*		0- отключить спавн презентов (по сути- временная приостановка работы плагина)
*/
native CmsPresentSetSpawnMode(iMode)

/** Получение точек спавна презентов из файла
*	@iOrigins - массив для записи координат точки спавна
*	return - 1- при наличии валидной точки спавна
*/
native CmsGetPresentsOriginsFromFile(Float:flOrigins[3])

/** Вызывается при остановке работы плагина GameCMS_Present (ядро)
*/
forward OnPresentCoreStopped()


/** Вызывается при попытке поднять презент, если он создан с параметром @prAccess- доступ: 0 - всем
*	@iClient - индекс игрока, который пытается поднять
*	@idKey - уникальный номер презента
*	@iEntity - индекс entity презента
*	return - возвращаемые значения:
*		0 - презент запрещено поднимать
*		1 - презент будет поднят, будет выведено стандартное сообщение о поднятии презента
*		2 - презент будет поднят, НЕ будет выводиться стандартное сообщение о поднятии презента
*		3 - презент НЕ будет поднят, НЕ будет выводиться сообщение о поднятии презента
*/
forward OnTakePresent(iClient, idKey, iEntity)


/** Вызывается при фактическом поднятии любого презента
*	@iClient - индекс игрока, поднявшего презент
*	@idKey - уникальный номер презента
*	@iEntity - индекс entity презента
*	return - функция ничего не возвращает
*/
forward OnTakePresentSave(iClient, idKey, iEntity)

/** Вызывается перед спавном презента
*	@idKey - уникальный номер презента
*	return - возвращаемые значения:
*		0 - презент не появится, будет вызван спавн следующего презента (если предусмотрено настройкой)
*		1 - презент появится с параметрами, заданными при создании
*/
forward OnValidateSpawnPresent(idKey)